Class: Google::Apis::LanguageV2::ModerateTextResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v2/classes.rb,
lib/google/apis/language_v2/representations.rb,
lib/google/apis/language_v2/representations.rb

Overview

The document moderation response message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ModerateTextResponse

Returns a new instance of ModerateTextResponse.



799
800
801
# File 'lib/google/apis/language_v2/classes.rb', line 799

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#language_codeString

The language of the text, which will be the same as the language specified in the request or, if not specified, the automatically-detected language. See Document.language_code field for more details. Corresponds to the JSON property languageCode

Returns:

  • (String)


785
786
787
# File 'lib/google/apis/language_v2/classes.rb', line 785

def language_code
  @language_code
end

#language_supportedBoolean Also known as: language_supported?

Whether the language is officially supported. The API may still return a response when the language is not supported, but it is on a best effort basis. Corresponds to the JSON property languageSupported

Returns:

  • (Boolean)


791
792
793
# File 'lib/google/apis/language_v2/classes.rb', line 791

def language_supported
  @language_supported
end

#moderation_categoriesArray<Google::Apis::LanguageV2::ClassificationCategory>

Harmful and sensitive categories representing the input document. Corresponds to the JSON property moderationCategories



797
798
799
# File 'lib/google/apis/language_v2/classes.rb', line 797

def moderation_categories
  @moderation_categories
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



804
805
806
807
808
# File 'lib/google/apis/language_v2/classes.rb', line 804

def update!(**args)
  @language_code = args[:language_code] if args.key?(:language_code)
  @language_supported = args[:language_supported] if args.key?(:language_supported)
  @moderation_categories = args[:moderation_categories] if args.key?(:moderation_categories)
end