Class: Google::Apis::LanguageV2::Sentence
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV2::Sentence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v2/classes.rb,
lib/google/apis/language_v2/representations.rb,
lib/google/apis/language_v2/representations.rb
Overview
Represents a sentence in the input document.
Instance Attribute Summary collapse
-
#sentiment ⇒ Google::Apis::LanguageV2::Sentiment
Represents the feeling associated with the entire text or entities in the text.
-
#text ⇒ Google::Apis::LanguageV2::TextSpan
Represents a text span in the input document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Sentence
constructor
A new instance of Sentence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Sentence
Returns a new instance of Sentence.
872 873 874 |
# File 'lib/google/apis/language_v2/classes.rb', line 872 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sentiment ⇒ Google::Apis::LanguageV2::Sentiment
Represents the feeling associated with the entire text or entities in the text.
Corresponds to the JSON property sentiment
865 866 867 |
# File 'lib/google/apis/language_v2/classes.rb', line 865 def sentiment @sentiment end |
#text ⇒ Google::Apis::LanguageV2::TextSpan
Represents a text span in the input document.
Corresponds to the JSON property text
870 871 872 |
# File 'lib/google/apis/language_v2/classes.rb', line 870 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
877 878 879 880 |
# File 'lib/google/apis/language_v2/classes.rb', line 877 def update!(**args) @sentiment = args[:sentiment] if args.key?(:sentiment) @text = args[:text] if args.key?(:text) end |