Class: Google::Apis::LanguageV2::XpsCategoryStatsSingleCategoryStats
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV2::XpsCategoryStatsSingleCategoryStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v2/classes.rb,
lib/google/apis/language_v2/representations.rb,
lib/google/apis/language_v2/representations.rb
Overview
The statistics of a single CATEGORY value.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
The number of occurrences of this value in the series.
-
#value ⇒ String
The CATEGORY value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsCategoryStatsSingleCategoryStats
constructor
A new instance of XpsCategoryStatsSingleCategoryStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsCategoryStatsSingleCategoryStats
Returns a new instance of XpsCategoryStatsSingleCategoryStats.
1153 1154 1155 |
# File 'lib/google/apis/language_v2/classes.rb', line 1153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
The number of occurrences of this value in the series.
Corresponds to the JSON property count
1146 1147 1148 |
# File 'lib/google/apis/language_v2/classes.rb', line 1146 def count @count end |
#value ⇒ String
The CATEGORY value.
Corresponds to the JSON property value
1151 1152 1153 |
# File 'lib/google/apis/language_v2/classes.rb', line 1151 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1158 1159 1160 1161 |
# File 'lib/google/apis/language_v2/classes.rb', line 1158 def update!(**args) @count = args[:count] if args.key?(:count) @value = args[:value] if args.key?(:value) end |