Class: Google::Apis::LanguageV2::XpsClassificationEvaluationMetrics
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV2::XpsClassificationEvaluationMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v2/classes.rb,
lib/google/apis/language_v2/representations.rb,
lib/google/apis/language_v2/representations.rb
Overview
Model evaluation metrics for classification problems. It can be used for image and video classification. Next tag: 9.
Instance Attribute Summary collapse
-
#au_prc ⇒ Float
The Area under precision recall curve metric.
-
#au_roc ⇒ Float
The Area Under Receiver Operating Characteristic curve metric.
-
#base_au_prc ⇒ Float
The Area under precision recall curve metric based on priors.
-
#confidence_metrics_entries ⇒ Array<Google::Apis::LanguageV2::XpsConfidenceMetricsEntry>
Metrics that have confidence thresholds.
-
#confusion_matrix ⇒ Google::Apis::LanguageV2::XpsConfusionMatrix
Confusion matrix of the model running the classification.
-
#evaluated_examples_count ⇒ Fixnum
The number of examples used for model evaluation.
-
#log_loss ⇒ Float
The Log Loss metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsClassificationEvaluationMetrics
constructor
A new instance of XpsClassificationEvaluationMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsClassificationEvaluationMetrics
Returns a new instance of XpsClassificationEvaluationMetrics.
1206 1207 1208 |
# File 'lib/google/apis/language_v2/classes.rb', line 1206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#au_prc ⇒ Float
The Area under precision recall curve metric.
Corresponds to the JSON property auPrc
1172 1173 1174 |
# File 'lib/google/apis/language_v2/classes.rb', line 1172 def au_prc @au_prc end |
#au_roc ⇒ Float
The Area Under Receiver Operating Characteristic curve metric. Micro-averaged
for the overall evaluation.
Corresponds to the JSON property auRoc
1178 1179 1180 |
# File 'lib/google/apis/language_v2/classes.rb', line 1178 def au_roc @au_roc end |
#base_au_prc ⇒ Float
The Area under precision recall curve metric based on priors.
Corresponds to the JSON property baseAuPrc
1183 1184 1185 |
# File 'lib/google/apis/language_v2/classes.rb', line 1183 def base_au_prc @base_au_prc end |
#confidence_metrics_entries ⇒ Array<Google::Apis::LanguageV2::XpsConfidenceMetricsEntry>
Metrics that have confidence thresholds. Precision-recall curve can be derived
from it.
Corresponds to the JSON property confidenceMetricsEntries
1189 1190 1191 |
# File 'lib/google/apis/language_v2/classes.rb', line 1189 def confidence_metrics_entries @confidence_metrics_entries end |
#confusion_matrix ⇒ Google::Apis::LanguageV2::XpsConfusionMatrix
Confusion matrix of the model running the classification.
Corresponds to the JSON property confusionMatrix
1194 1195 1196 |
# File 'lib/google/apis/language_v2/classes.rb', line 1194 def confusion_matrix @confusion_matrix end |
#evaluated_examples_count ⇒ Fixnum
The number of examples used for model evaluation.
Corresponds to the JSON property evaluatedExamplesCount
1199 1200 1201 |
# File 'lib/google/apis/language_v2/classes.rb', line 1199 def evaluated_examples_count @evaluated_examples_count end |
#log_loss ⇒ Float
The Log Loss metric.
Corresponds to the JSON property logLoss
1204 1205 1206 |
# File 'lib/google/apis/language_v2/classes.rb', line 1204 def log_loss @log_loss end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1211 1212 1213 1214 1215 1216 1217 1218 1219 |
# File 'lib/google/apis/language_v2/classes.rb', line 1211 def update!(**args) @au_prc = args[:au_prc] if args.key?(:au_prc) @au_roc = args[:au_roc] if args.key?(:au_roc) @base_au_prc = args[:base_au_prc] if args.key?(:base_au_prc) @confidence_metrics_entries = args[:confidence_metrics_entries] if args.key?(:confidence_metrics_entries) @confusion_matrix = args[:confusion_matrix] if args.key?(:confusion_matrix) @evaluated_examples_count = args[:evaluated_examples_count] if args.key?(:evaluated_examples_count) @log_loss = args[:log_loss] if args.key?(:log_loss) end |