Class: Google::Apis::LanguageV2::XpsConfidenceMetricsEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v2/classes.rb,
lib/google/apis/language_v2/representations.rb,
lib/google/apis/language_v2/representations.rb

Overview

ConfidenceMetricsEntry includes generic precision, recall, f1 score etc. Next tag: 16.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsConfidenceMetricsEntry

Returns a new instance of XpsConfidenceMetricsEntry.



1553
1554
1555
# File 'lib/google/apis/language_v2/classes.rb', line 1553

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

Metrics are computed with an assumption that the model never return predictions with score lower than this value. Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


1478
1479
1480
# File 'lib/google/apis/language_v2/classes.rb', line 1478

def confidence_threshold
  @confidence_threshold
end

#f1_scoreFloat

The harmonic mean of recall and precision. Corresponds to the JSON property f1Score

Returns:

  • (Float)


1483
1484
1485
# File 'lib/google/apis/language_v2/classes.rb', line 1483

def f1_score
  @f1_score
end

#f1_score_at1Float

The harmonic mean of recall_at1 and precision_at1. Corresponds to the JSON property f1ScoreAt1

Returns:

  • (Float)


1488
1489
1490
# File 'lib/google/apis/language_v2/classes.rb', line 1488

def f1_score_at1
  @f1_score_at1
end

#false_negative_countFixnum

The number of ground truth labels that are not matched by a model created label. Corresponds to the JSON property falseNegativeCount

Returns:

  • (Fixnum)


1494
1495
1496
# File 'lib/google/apis/language_v2/classes.rb', line 1494

def false_negative_count
  @false_negative_count
end

#false_positive_countFixnum

The number of model created labels that do not match a ground truth label. Corresponds to the JSON property falsePositiveCount

Returns:

  • (Fixnum)


1499
1500
1501
# File 'lib/google/apis/language_v2/classes.rb', line 1499

def false_positive_count
  @false_positive_count
end

#false_positive_rateFloat

False Positive Rate for the given confidence threshold. Corresponds to the JSON property falsePositiveRate

Returns:

  • (Float)


1504
1505
1506
# File 'lib/google/apis/language_v2/classes.rb', line 1504

def false_positive_rate
  @false_positive_rate
end

#false_positive_rate_at1Float

The False Positive Rate when only considering the label that has the highest prediction score and not below the confidence threshold for each example. Corresponds to the JSON property falsePositiveRateAt1

Returns:

  • (Float)


1510
1511
1512
# File 'lib/google/apis/language_v2/classes.rb', line 1510

def false_positive_rate_at1
  @false_positive_rate_at1
end

#position_thresholdFixnum

Metrics are computed with an assumption that the model always returns at most this many predictions (ordered by their score, descendingly), but they all still need to meet the confidence_threshold. Corresponds to the JSON property positionThreshold

Returns:

  • (Fixnum)


1517
1518
1519
# File 'lib/google/apis/language_v2/classes.rb', line 1517

def position_threshold
  @position_threshold
end

#precisionFloat

Precision for the given confidence threshold. Corresponds to the JSON property precision

Returns:

  • (Float)


1522
1523
1524
# File 'lib/google/apis/language_v2/classes.rb', line 1522

def precision
  @precision
end

#precision_at1Float

The precision when only considering the label that has the highest prediction score and not below the confidence threshold for each example. Corresponds to the JSON property precisionAt1

Returns:

  • (Float)


1528
1529
1530
# File 'lib/google/apis/language_v2/classes.rb', line 1528

def precision_at1
  @precision_at1
end

#recallFloat

Recall (true positive rate) for the given confidence threshold. Corresponds to the JSON property recall

Returns:

  • (Float)


1533
1534
1535
# File 'lib/google/apis/language_v2/classes.rb', line 1533

def recall
  @recall
end

#recall_at1Float

The recall (true positive rate) when only considering the label that has the highest prediction score and not below the confidence threshold for each example. Corresponds to the JSON property recallAt1

Returns:

  • (Float)


1540
1541
1542
# File 'lib/google/apis/language_v2/classes.rb', line 1540

def recall_at1
  @recall_at1
end

#true_negative_countFixnum

The number of labels that were not created by the model, but if they would, they would not match a ground truth label. Corresponds to the JSON property trueNegativeCount

Returns:

  • (Fixnum)


1546
1547
1548
# File 'lib/google/apis/language_v2/classes.rb', line 1546

def true_negative_count
  @true_negative_count
end

#true_positive_countFixnum

The number of model created labels that match a ground truth label. Corresponds to the JSON property truePositiveCount

Returns:

  • (Fixnum)


1551
1552
1553
# File 'lib/google/apis/language_v2/classes.rb', line 1551

def true_positive_count
  @true_positive_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
# File 'lib/google/apis/language_v2/classes.rb', line 1558

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @f1_score = args[:f1_score] if args.key?(:f1_score)
  @f1_score_at1 = args[:f1_score_at1] if args.key?(:f1_score_at1)
  @false_negative_count = args[:false_negative_count] if args.key?(:false_negative_count)
  @false_positive_count = args[:false_positive_count] if args.key?(:false_positive_count)
  @false_positive_rate = args[:false_positive_rate] if args.key?(:false_positive_rate)
  @false_positive_rate_at1 = args[:false_positive_rate_at1] if args.key?(:false_positive_rate_at1)
  @position_threshold = args[:position_threshold] if args.key?(:position_threshold)
  @precision = args[:precision] if args.key?(:precision)
  @precision_at1 = args[:precision_at1] if args.key?(:precision_at1)
  @recall = args[:recall] if args.key?(:recall)
  @recall_at1 = args[:recall_at1] if args.key?(:recall_at1)
  @true_negative_count = args[:true_negative_count] if args.key?(:true_negative_count)
  @true_positive_count = args[:true_positive_count] if args.key?(:true_positive_count)
end