Class: Google::Apis::LanguageV2::XpsDockerFormat

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v2/classes.rb,
lib/google/apis/language_v2/representations.rb,
lib/google/apis/language_v2/representations.rb

Overview

A model format used for Docker containers. Use the params field to customize the container. The container is verified to work correctly on ubuntu 16.04 operating system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsDockerFormat

Returns a new instance of XpsDockerFormat.



1850
1851
1852
# File 'lib/google/apis/language_v2/classes.rb', line 1850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpu_architectureString

Optional. Additional cpu information describing the requirements for the to be exported model files. Corresponds to the JSON property cpuArchitecture

Returns:

  • (String)


1842
1843
1844
# File 'lib/google/apis/language_v2/classes.rb', line 1842

def cpu_architecture
  @cpu_architecture
end

#gpu_architectureString

Optional. Additional gpu information describing the requirements for the to be exported model files. Corresponds to the JSON property gpuArchitecture

Returns:

  • (String)


1848
1849
1850
# File 'lib/google/apis/language_v2/classes.rb', line 1848

def gpu_architecture
  @gpu_architecture
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1855
1856
1857
1858
# File 'lib/google/apis/language_v2/classes.rb', line 1855

def update!(**args)
  @cpu_architecture = args[:cpu_architecture] if args.key?(:cpu_architecture)
  @gpu_architecture = args[:gpu_architecture] if args.key?(:gpu_architecture)
end