Class: Google::Apis::LanguageV2::XpsEvaluationMetrics
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV2::XpsEvaluationMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v2/classes.rb,
lib/google/apis/language_v2/representations.rb,
lib/google/apis/language_v2/representations.rb
Overview
Contains xPS-specific model evaluation metrics either for a single annotation spec (label), or for the model overall. Next tag: 18.
Instance Attribute Summary collapse
-
#annotation_spec_id_token ⇒ String
The annotation_spec for which this evaluation metrics instance had been created.
-
#category ⇒ Fixnum
The integer category label for which this evaluation metric instance had been created.
-
#evaluated_example_count ⇒ Fixnum
The number of examples used to create this evaluation metrics instance.
-
#image_classification_eval_metrics ⇒ Google::Apis::LanguageV2::XpsClassificationEvaluationMetrics
Model evaluation metrics for classification problems.
-
#image_object_detection_eval_metrics ⇒ Google::Apis::LanguageV2::XpsImageObjectDetectionEvaluationMetrics
Model evaluation metrics for image object detection problems.
-
#image_segmentation_eval_metrics ⇒ Google::Apis::LanguageV2::XpsImageSegmentationEvaluationMetrics
Model evaluation metrics for image segmentation problems.
-
#label ⇒ String
The label for which this evaluation metrics instance had been created.
-
#regression_eval_metrics ⇒ Google::Apis::LanguageV2::XpsRegressionEvaluationMetrics
Model evaluation metrics for regression problems.
-
#tables_classification_eval_metrics ⇒ Google::Apis::LanguageV2::XpsClassificationEvaluationMetrics
Model evaluation metrics for classification problems.
-
#tables_eval_metrics ⇒ Google::Apis::LanguageV2::XpsTablesEvaluationMetrics
Corresponds to the JSON property
tablesEvalMetrics. -
#text_classification_eval_metrics ⇒ Google::Apis::LanguageV2::XpsClassificationEvaluationMetrics
Model evaluation metrics for classification problems.
-
#text_extraction_eval_metrics ⇒ Google::Apis::LanguageV2::XpsTextExtractionEvaluationMetrics
Corresponds to the JSON property
textExtractionEvalMetrics. -
#text_sentiment_eval_metrics ⇒ Google::Apis::LanguageV2::XpsTextSentimentEvaluationMetrics
Model evaluation metrics for text sentiment problems.
-
#translation_eval_metrics ⇒ Google::Apis::LanguageV2::XpsTranslationEvaluationMetrics
Evaluation metrics for the dataset.
-
#video_action_recognition_eval_metrics ⇒ Google::Apis::LanguageV2::XpsVideoActionRecognitionEvaluationMetrics
Model evaluation metrics for video action recognition.
-
#video_classification_eval_metrics ⇒ Google::Apis::LanguageV2::XpsClassificationEvaluationMetrics
Model evaluation metrics for classification problems.
-
#video_object_tracking_eval_metrics ⇒ Google::Apis::LanguageV2::XpsVideoObjectTrackingEvaluationMetrics
Model evaluation metrics for ObjectTracking problems.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsEvaluationMetrics
constructor
A new instance of XpsEvaluationMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsEvaluationMetrics
Returns a new instance of XpsEvaluationMetrics.
1981 1982 1983 |
# File 'lib/google/apis/language_v2/classes.rb', line 1981 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_spec_id_token ⇒ String
The annotation_spec for which this evaluation metrics instance had been
created. Empty iff this is an overall model evaluation (like Tables evaluation
metrics), i.e. aggregated across all labels. The value comes from the input
annotations in AnnotatedExample. For MVP product or for text sentiment models
where annotation_spec_id_token is not available, set label instead.
Corresponds to the JSON property annotationSpecIdToken
1886 1887 1888 |
# File 'lib/google/apis/language_v2/classes.rb', line 1886 def annotation_spec_id_token @annotation_spec_id_token end |
#category ⇒ Fixnum
The integer category label for which this evaluation metric instance had been
created. Valid categories are 0 or higher. Overall model evaluation should set
this to negative values (rather than implicit zero). Only used for Image
Segmentation (prefer to set annotation_spec_id_token instead). Note: uCAIP
Image Segmentation should use annotation_spec_id_token.
Corresponds to the JSON property category
1895 1896 1897 |
# File 'lib/google/apis/language_v2/classes.rb', line 1895 def category @category end |
#evaluated_example_count ⇒ Fixnum
The number of examples used to create this evaluation metrics instance.
Corresponds to the JSON property evaluatedExampleCount
1900 1901 1902 |
# File 'lib/google/apis/language_v2/classes.rb', line 1900 def evaluated_example_count @evaluated_example_count end |
#image_classification_eval_metrics ⇒ Google::Apis::LanguageV2::XpsClassificationEvaluationMetrics
Model evaluation metrics for classification problems. It can be used for image
and video classification. Next tag: 9.
Corresponds to the JSON property imageClassificationEvalMetrics
1906 1907 1908 |
# File 'lib/google/apis/language_v2/classes.rb', line 1906 def image_classification_eval_metrics @image_classification_eval_metrics end |
#image_object_detection_eval_metrics ⇒ Google::Apis::LanguageV2::XpsImageObjectDetectionEvaluationMetrics
Model evaluation metrics for image object detection problems. Evaluates
prediction quality of labeled bounding boxes.
Corresponds to the JSON property imageObjectDetectionEvalMetrics
1912 1913 1914 |
# File 'lib/google/apis/language_v2/classes.rb', line 1912 def image_object_detection_eval_metrics @image_object_detection_eval_metrics end |
#image_segmentation_eval_metrics ⇒ Google::Apis::LanguageV2::XpsImageSegmentationEvaluationMetrics
Model evaluation metrics for image segmentation problems. Next tag: 4.
Corresponds to the JSON property imageSegmentationEvalMetrics
1917 1918 1919 |
# File 'lib/google/apis/language_v2/classes.rb', line 1917 def image_segmentation_eval_metrics @image_segmentation_eval_metrics end |
#label ⇒ String
The label for which this evaluation metrics instance had been created. Empty
iff this is an overall model evaluation (like Tables evaluation metrics), i.e.
aggregated across all labels. The label maps to AnnotationSpec.display_name in
Public API protos. Only used by MVP implementation and text sentiment FULL
implementation.
Corresponds to the JSON property label
1926 1927 1928 |
# File 'lib/google/apis/language_v2/classes.rb', line 1926 def label @label end |
#regression_eval_metrics ⇒ Google::Apis::LanguageV2::XpsRegressionEvaluationMetrics
Model evaluation metrics for regression problems. It can be used for Tables.
Corresponds to the JSON property regressionEvalMetrics
1931 1932 1933 |
# File 'lib/google/apis/language_v2/classes.rb', line 1931 def regression_eval_metrics @regression_eval_metrics end |
#tables_classification_eval_metrics ⇒ Google::Apis::LanguageV2::XpsClassificationEvaluationMetrics
Model evaluation metrics for classification problems. It can be used for image
and video classification. Next tag: 9.
Corresponds to the JSON property tablesClassificationEvalMetrics
1937 1938 1939 |
# File 'lib/google/apis/language_v2/classes.rb', line 1937 def tables_classification_eval_metrics @tables_classification_eval_metrics end |
#tables_eval_metrics ⇒ Google::Apis::LanguageV2::XpsTablesEvaluationMetrics
Corresponds to the JSON property tablesEvalMetrics
1942 1943 1944 |
# File 'lib/google/apis/language_v2/classes.rb', line 1942 def tables_eval_metrics @tables_eval_metrics end |
#text_classification_eval_metrics ⇒ Google::Apis::LanguageV2::XpsClassificationEvaluationMetrics
Model evaluation metrics for classification problems. It can be used for image
and video classification. Next tag: 9.
Corresponds to the JSON property textClassificationEvalMetrics
1948 1949 1950 |
# File 'lib/google/apis/language_v2/classes.rb', line 1948 def text_classification_eval_metrics @text_classification_eval_metrics end |
#text_extraction_eval_metrics ⇒ Google::Apis::LanguageV2::XpsTextExtractionEvaluationMetrics
Corresponds to the JSON property textExtractionEvalMetrics
1953 1954 1955 |
# File 'lib/google/apis/language_v2/classes.rb', line 1953 def text_extraction_eval_metrics @text_extraction_eval_metrics end |
#text_sentiment_eval_metrics ⇒ Google::Apis::LanguageV2::XpsTextSentimentEvaluationMetrics
Model evaluation metrics for text sentiment problems.
Corresponds to the JSON property textSentimentEvalMetrics
1958 1959 1960 |
# File 'lib/google/apis/language_v2/classes.rb', line 1958 def text_sentiment_eval_metrics @text_sentiment_eval_metrics end |
#translation_eval_metrics ⇒ Google::Apis::LanguageV2::XpsTranslationEvaluationMetrics
Evaluation metrics for the dataset.
Corresponds to the JSON property translationEvalMetrics
1963 1964 1965 |
# File 'lib/google/apis/language_v2/classes.rb', line 1963 def translation_eval_metrics @translation_eval_metrics end |
#video_action_recognition_eval_metrics ⇒ Google::Apis::LanguageV2::XpsVideoActionRecognitionEvaluationMetrics
Model evaluation metrics for video action recognition.
Corresponds to the JSON property videoActionRecognitionEvalMetrics
1968 1969 1970 |
# File 'lib/google/apis/language_v2/classes.rb', line 1968 def video_action_recognition_eval_metrics @video_action_recognition_eval_metrics end |
#video_classification_eval_metrics ⇒ Google::Apis::LanguageV2::XpsClassificationEvaluationMetrics
Model evaluation metrics for classification problems. It can be used for image
and video classification. Next tag: 9.
Corresponds to the JSON property videoClassificationEvalMetrics
1974 1975 1976 |
# File 'lib/google/apis/language_v2/classes.rb', line 1974 def video_classification_eval_metrics @video_classification_eval_metrics end |
#video_object_tracking_eval_metrics ⇒ Google::Apis::LanguageV2::XpsVideoObjectTrackingEvaluationMetrics
Model evaluation metrics for ObjectTracking problems. Next tag: 10.
Corresponds to the JSON property videoObjectTrackingEvalMetrics
1979 1980 1981 |
# File 'lib/google/apis/language_v2/classes.rb', line 1979 def video_object_tracking_eval_metrics @video_object_tracking_eval_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 |
# File 'lib/google/apis/language_v2/classes.rb', line 1986 def update!(**args) @annotation_spec_id_token = args[:annotation_spec_id_token] if args.key?(:annotation_spec_id_token) @category = args[:category] if args.key?(:category) @evaluated_example_count = args[:evaluated_example_count] if args.key?(:evaluated_example_count) @image_classification_eval_metrics = args[:image_classification_eval_metrics] if args.key?(:image_classification_eval_metrics) @image_object_detection_eval_metrics = args[:image_object_detection_eval_metrics] if args.key?(:image_object_detection_eval_metrics) @image_segmentation_eval_metrics = args[:image_segmentation_eval_metrics] if args.key?(:image_segmentation_eval_metrics) @label = args[:label] if args.key?(:label) @regression_eval_metrics = args[:regression_eval_metrics] if args.key?(:regression_eval_metrics) @tables_classification_eval_metrics = args[:tables_classification_eval_metrics] if args.key?(:tables_classification_eval_metrics) @tables_eval_metrics = args[:tables_eval_metrics] if args.key?(:tables_eval_metrics) @text_classification_eval_metrics = args[:text_classification_eval_metrics] if args.key?(:text_classification_eval_metrics) @text_extraction_eval_metrics = args[:text_extraction_eval_metrics] if args.key?(:text_extraction_eval_metrics) @text_sentiment_eval_metrics = args[:text_sentiment_eval_metrics] if args.key?(:text_sentiment_eval_metrics) @translation_eval_metrics = args[:translation_eval_metrics] if args.key?(:translation_eval_metrics) @video_action_recognition_eval_metrics = args[:video_action_recognition_eval_metrics] if args.key?(:video_action_recognition_eval_metrics) @video_classification_eval_metrics = args[:video_classification_eval_metrics] if args.key?(:video_classification_eval_metrics) @video_object_tracking_eval_metrics = args[:video_object_tracking_eval_metrics] if args.key?(:video_object_tracking_eval_metrics) end |