Class: Google::Apis::LanguageV2::XpsExportModelOutputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v2/classes.rb,
lib/google/apis/language_v2/representations.rb,
lib/google/apis/language_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsExportModelOutputConfig

Returns a new instance of XpsExportModelOutputConfig.



2135
2136
2137
# File 'lib/google/apis/language_v2/classes.rb', line 2135

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#core_ml_formatGoogle::Apis::LanguageV2::XpsCoreMlFormat

A model format used for iOS mobile devices. Corresponds to the JSON property coreMlFormat



2085
2086
2087
# File 'lib/google/apis/language_v2/classes.rb', line 2085

def core_ml_format
  @core_ml_format
end

#docker_formatGoogle::Apis::LanguageV2::XpsDockerFormat

A model format used for Docker containers. Use the params field to customize the container. The container is verified to work correctly on ubuntu 16.04 operating system. Corresponds to the JSON property dockerFormat



2092
2093
2094
# File 'lib/google/apis/language_v2/classes.rb', line 2092

def docker_format
  @docker_format
end

#edge_tpu_tf_lite_formatGoogle::Apis::LanguageV2::XpsEdgeTpuTfLiteFormat

A model format used for Edge TPU devices. Corresponds to the JSON property edgeTpuTfLiteFormat



2097
2098
2099
# File 'lib/google/apis/language_v2/classes.rb', line 2097

def edge_tpu_tf_lite_format
  @edge_tpu_tf_lite_format
end

#export_firebase_auxiliary_infoBoolean Also known as: export_firebase_auxiliary_info?

For any model and format: If true, will additionally export FirebaseExportedModelInfo in a firebase.txt file. Corresponds to the JSON property exportFirebaseAuxiliaryInfo

Returns:

  • (Boolean)


2103
2104
2105
# File 'lib/google/apis/language_v2/classes.rb', line 2103

def export_firebase_auxiliary_info
  @export_firebase_auxiliary_info
end

#output_gcr_uriString

The Google Contained Registry path the exported files to be pushed to. This location is set if the exported format is DOCKDER. Corresponds to the JSON property outputGcrUri

Returns:

  • (String)


2110
2111
2112
# File 'lib/google/apis/language_v2/classes.rb', line 2110

def output_gcr_uri
  @output_gcr_uri
end

#output_gcs_uriString

The Google Cloud Storage directory where XPS will output the exported models and related files. Format: gs://bucket/directory Corresponds to the JSON property outputGcsUri

Returns:

  • (String)


2116
2117
2118
# File 'lib/google/apis/language_v2/classes.rb', line 2116

def output_gcs_uri
  @output_gcs_uri
end

#tf_js_formatGoogle::Apis::LanguageV2::XpsTfJsFormat

A TensorFlow.js model that can be used in the browser and in Node.js using JavaScript. Corresponds to the JSON property tfJsFormat



2122
2123
2124
# File 'lib/google/apis/language_v2/classes.rb', line 2122

def tf_js_format
  @tf_js_format
end

#tf_lite_formatGoogle::Apis::LanguageV2::XpsTfLiteFormat

LINT.IfChange A model format used for mobile and IoT devices. See https://www. tensorflow.org/lite. Corresponds to the JSON property tfLiteFormat



2128
2129
2130
# File 'lib/google/apis/language_v2/classes.rb', line 2128

def tf_lite_format
  @tf_lite_format
end

#tf_saved_model_formatGoogle::Apis::LanguageV2::XpsTfSavedModelFormat

A tensorflow model format in SavedModel format. Corresponds to the JSON property tfSavedModelFormat



2133
2134
2135
# File 'lib/google/apis/language_v2/classes.rb', line 2133

def tf_saved_model_format
  @tf_saved_model_format
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
# File 'lib/google/apis/language_v2/classes.rb', line 2140

def update!(**args)
  @core_ml_format = args[:core_ml_format] if args.key?(:core_ml_format)
  @docker_format = args[:docker_format] if args.key?(:docker_format)
  @edge_tpu_tf_lite_format = args[:edge_tpu_tf_lite_format] if args.key?(:edge_tpu_tf_lite_format)
  @export_firebase_auxiliary_info = args[:export_firebase_auxiliary_info] if args.key?(:export_firebase_auxiliary_info)
  @output_gcr_uri = args[:output_gcr_uri] if args.key?(:output_gcr_uri)
  @output_gcs_uri = args[:output_gcs_uri] if args.key?(:output_gcs_uri)
  @tf_js_format = args[:tf_js_format] if args.key?(:tf_js_format)
  @tf_lite_format = args[:tf_lite_format] if args.key?(:tf_lite_format)
  @tf_saved_model_format = args[:tf_saved_model_format] if args.key?(:tf_saved_model_format)
end