Class: Google::Apis::LanguageV2::XpsColumnSpec
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV2::XpsColumnSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v2/classes.rb,
lib/google/apis/language_v2/representations.rb,
lib/google/apis/language_v2/representations.rb
Instance Attribute Summary collapse
-
#column_id ⇒ Fixnum
The unique id of the column.
-
#data_stats ⇒ Google::Apis::LanguageV2::XpsDataStats
The data statistics of a series of values that share the same DataType.
-
#data_type ⇒ Google::Apis::LanguageV2::XpsDataType
Indicated the type of data that can be stored in a structured data entity (e.g. a table).
-
#display_name ⇒ String
The display name of the column.
-
#forecasting_metadata ⇒ Google::Apis::LanguageV2::XpsColumnSpecForecastingMetadata
Corresponds to the JSON property
forecastingMetadata. -
#top_correlated_columns ⇒ Array<Google::Apis::LanguageV2::XpsColumnSpecCorrelatedColumn>
It's outputed in RefreshTablesStats, and a required input in Train.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsColumnSpec
constructor
A new instance of XpsColumnSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsColumnSpec
Returns a new instance of XpsColumnSpec.
1376 1377 1378 |
# File 'lib/google/apis/language_v2/classes.rb', line 1376 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column_id ⇒ Fixnum
The unique id of the column. When Preprocess, the Tables BE will popuate the
order id of the column, which reflects the order of the column inside the
table, i.e. 0 means the first column in the table, N-1 means the last column.
AutoML BE will persist this order id in Spanner and set the order id here when
calling RefreshTablesStats and Train. Note: it's different than the
column_spec_id that is generated in AutoML BE.
Corresponds to the JSON property columnId
1347 1348 1349 |
# File 'lib/google/apis/language_v2/classes.rb', line 1347 def column_id @column_id end |
#data_stats ⇒ Google::Apis::LanguageV2::XpsDataStats
The data statistics of a series of values that share the same DataType.
Corresponds to the JSON property dataStats
1352 1353 1354 |
# File 'lib/google/apis/language_v2/classes.rb', line 1352 def data_stats @data_stats end |
#data_type ⇒ Google::Apis::LanguageV2::XpsDataType
Indicated the type of data that can be stored in a structured data entity (e.g.
a table).
Corresponds to the JSON property dataType
1358 1359 1360 |
# File 'lib/google/apis/language_v2/classes.rb', line 1358 def data_type @data_type end |
#display_name ⇒ String
The display name of the column. It's outputed in Preprocess and a required
input for RefreshTablesStats and Train.
Corresponds to the JSON property displayName
1364 1365 1366 |
# File 'lib/google/apis/language_v2/classes.rb', line 1364 def display_name @display_name end |
#forecasting_metadata ⇒ Google::Apis::LanguageV2::XpsColumnSpecForecastingMetadata
Corresponds to the JSON property forecastingMetadata
1369 1370 1371 |
# File 'lib/google/apis/language_v2/classes.rb', line 1369 def @forecasting_metadata end |
#top_correlated_columns ⇒ Array<Google::Apis::LanguageV2::XpsColumnSpecCorrelatedColumn>
It's outputed in RefreshTablesStats, and a required input in Train.
Corresponds to the JSON property topCorrelatedColumns
1374 1375 1376 |
# File 'lib/google/apis/language_v2/classes.rb', line 1374 def @top_correlated_columns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/google/apis/language_v2/classes.rb', line 1381 def update!(**args) @column_id = args[:column_id] if args.key?(:column_id) @data_stats = args[:data_stats] if args.key?(:data_stats) @data_type = args[:data_type] if args.key?(:data_type) @display_name = args[:display_name] if args.key?(:display_name) @forecasting_metadata = args[:forecasting_metadata] if args.key?(:forecasting_metadata) @top_correlated_columns = args[:top_correlated_columns] if args.key?(:top_correlated_columns) end |