Class: Google::Apis::LanguageV2::XpsExampleSet
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV2::XpsExampleSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v2/classes.rb,
lib/google/apis/language_v2/representations.rb,
lib/google/apis/language_v2/representations.rb
Overview
Set of examples or input sources.
Instance Attribute Summary collapse
-
#file_spec ⇒ Google::Apis::LanguageV2::XpsFileSpec
Spec of input and output files, on external file systems (for example, Colossus Namespace System or Google Cloud Storage).
-
#fingerprint ⇒ Fixnum
Fingerprint of the example set.
-
#num_examples ⇒ Fixnum
Number of examples.
-
#num_input_sources ⇒ Fixnum
Number of input sources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsExampleSet
constructor
A new instance of XpsExampleSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsExampleSet
Returns a new instance of XpsExampleSet.
2065 2066 2067 |
# File 'lib/google/apis/language_v2/classes.rb', line 2065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_spec ⇒ Google::Apis::LanguageV2::XpsFileSpec
Spec of input and output files, on external file systems (for example,
Colossus Namespace System or Google Cloud Storage).
Corresponds to the JSON property fileSpec
2048 2049 2050 |
# File 'lib/google/apis/language_v2/classes.rb', line 2048 def file_spec @file_spec end |
#fingerprint ⇒ Fixnum
Fingerprint of the example set.
Corresponds to the JSON property fingerprint
2053 2054 2055 |
# File 'lib/google/apis/language_v2/classes.rb', line 2053 def fingerprint @fingerprint end |
#num_examples ⇒ Fixnum
Number of examples.
Corresponds to the JSON property numExamples
2058 2059 2060 |
# File 'lib/google/apis/language_v2/classes.rb', line 2058 def num_examples @num_examples end |
#num_input_sources ⇒ Fixnum
Number of input sources.
Corresponds to the JSON property numInputSources
2063 2064 2065 |
# File 'lib/google/apis/language_v2/classes.rb', line 2063 def num_input_sources @num_input_sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2070 2071 2072 2073 2074 2075 |
# File 'lib/google/apis/language_v2/classes.rb', line 2070 def update!(**args) @file_spec = args[:file_spec] if args.key?(:file_spec) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @num_examples = args[:num_examples] if args.key?(:num_examples) @num_input_sources = args[:num_input_sources] if args.key?(:num_input_sources) end |